pub struct DeviceBuffer {
pub data: Vec<u8>,
pub count: usize,
pub element_type: ElementType,
}Expand description
CPU-side buffer representing device memory.
Fields
data: Vec<u8>Raw bytes of the buffer.
count: usizeNumber of elements in the buffer.
element_type: ElementTypeElement data type.
Implementations
Sourceimpl DeviceBuffer
impl DeviceBuffer
Sourcepub fn to_f32(&self) -> Result<Vec<f32>, RuntimeError>
pub fn to_f32(&self) -> Result<Vec<f32>, RuntimeError>
Read buffer contents as f32 values.
Errors
Returns RuntimeError::Memory if the buffer element type is not f32.
Sourcepub fn to_u32(&self) -> Result<Vec<u32>, RuntimeError>
pub fn to_u32(&self) -> Result<Vec<u32>, RuntimeError>
Read buffer contents as u32 values.
Errors
Returns RuntimeError::Memory if the buffer element type is not u32.
Sourcepub fn size_bytes(&self) -> usize
pub fn size_bytes(&self) -> usize
Total size of the buffer in bytes.